"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _tv = _interopRequireDefault(require("tv4"));
var _assert = _interopRequireDefault(require("assert"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
// @CamillaTeodoro we are adding the assertValid function in the end of the file.
// At this point Typescript doesn't know that assertValid exists
// eslint-disable-next-line @typescript-eslint/ban-ts-comment
// @ts-ignore
const clonedTv4 = _tv.default.freshApi();
const allowNull = (data, schema) => {
  var _schema$type;
  return data === null && (schema.type === 'null' || ((_schema$type = schema.type) === null || _schema$type === void 0 ? void 0 : _schema$type.includes('null')) === true);
};
clonedTv4.addFormat('objectid', (data, schema) => {
  if (allowNull(data, schema)) return null;
  if (typeof data === 'string' && /^[a-f\d]{24}$/i.test(data)) return null;
  return 'objectid expected';
});
clonedTv4.addFormat('date-time', (data, schema) => {
  if (allowNull(data, schema)) return null;
  // Source: http://stackoverflow.com/questions/3143070/javascript-regex-iso-datetime
  const dateTimeRegex = /\d{4}-[01]\d-[0-3]\dT[0-2]\d:[0-5]\d:[0-5]\d\.\d+([+-][0-2]\d:[0-5]\d|Z)/;
  if (typeof data === 'string' && dateTimeRegex.test(data)) return null;
  return 'date-time, ISOString format, expected';
});
clonedTv4.addFormat('date', (data, schema) => {
  if (allowNull(data, schema)) return null;
  if (typeof data === 'string' && /\d{4}-[01]\d-[0-3]\d/.test(data)) return null;
  return 'date, YYYY-MM-DD format, expected';
});
clonedTv4.addFormat('time', (data, schema) => {
  if (allowNull(data, schema)) return null;
  if (typeof data === 'string' && /^[0-2][0-9]:[0-5][0-9](:[0-5][0-9])?$/.test(data)) return null;
  return 'time, HH:mm:ss or HH:mm format, expected';
});
clonedTv4.addFormat('email', (data, schema) => {
  if (allowNull(data, schema)) return null;
  // Source: http://stackoverflow.com/questions/46155/validate-email-address-in-javascript
  const emailRegex = /[a-z0-9!#$%&'*+/=?^_`{|}~-]+(?:\.[a-z0-9!#$%&'*+/=?^_`{|}~-]+)*@(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?/;
  if (typeof data === 'string' && emailRegex.test(data)) return null;
  return 'email expected';
});
clonedTv4.addFormat('non-negative-integer', (data, schema) => {
  if (allowNull(data, schema)) return null;
  if (typeof data === 'string' && /^[0-9]+$/.test(data)) return null;
  return 'non negative integer expected';
});
clonedTv4.assertValid = function (data, schema, errorMessage, {
  banUnknownProperties
} = {
  banUnknownProperties: true
}) {
  (0, _assert.default)(typeof schema === 'object', 'schema must be an object');
  if (errorMessage != null) (0, _assert.default)(typeof errorMessage === 'string', 'errorMessage must be a string');
  const {
    valid,
    error
  } = clonedTv4.validateResult(data, schema, false, banUnknownProperties ?? true);
  if (!valid) {
    const message = (() => {
      let result = '';
      if (errorMessage) result += `${errorMessage}; `;
      result += 'failed';
      if (schema.title) result += ` "${String(schema.title)}"`;
      result += ' schema validation';
      if (error.schemaPath) result += ` at schema path ${String(error.schemaPath)}`;
      if (error.dataPath) result += ` for data path ${String(error.dataPath)}`;
      result += `; ${String(error.message).toLowerCase()}`;
      return result;
    })();
    error.name = 'SchemaValidationError';
    error.message = message;
    error.data = data;
    error.schema = schema;
    // @CamillaTeodoro this error is from the tv4 library
    // eslint-disable-next-line @typescript-eslint/no-throw-literal
    throw error;
  }
};
var _default = clonedTv4;
exports.default = _default;